summaryrefslogtreecommitdiff
path: root/sys/arch/aviion
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2007-11-06 21:42:57 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2007-11-06 21:42:57 +0000
commitba416710b9c76049b048214a4d74b14973c2e019 (patch)
tree511ee5c2aa536bc5e4527d2c399f3f2594b06b69 /sys/arch/aviion
parent21f8fd673c0b6267dd6bcfd06e73e7cff03acf5d (diff)
Remove the now unused idle_u, and call the secondary processors startup
stack a startup stack.
Diffstat (limited to 'sys/arch/aviion')
-rw-r--r--sys/arch/aviion/aviion/locore.S14
-rw-r--r--sys/arch/aviion/aviion/machdep.c12
2 files changed, 10 insertions, 16 deletions
diff --git a/sys/arch/aviion/aviion/locore.S b/sys/arch/aviion/aviion/locore.S
index dae5f31e0c4..0bfe3e69713 100644
--- a/sys/arch/aviion/aviion/locore.S
+++ b/sys/arch/aviion/aviion/locore.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: locore.S,v 1.4 2007/10/10 15:53:51 art Exp $ */
+/* $OpenBSD: locore.S,v 1.5 2007/11/06 21:42:55 miod Exp $ */
/*
* Copyright (c) 2005, Miodrag Vallat.
* Copyright (c) 1998 Steve Murphree, Jr.
@@ -339,9 +339,9 @@ GLOBAL(secondary_start)
bsr _C_LABEL(secondary_pre_main) /* set cpu number */
ldcr r2, CPU
- ld r3, r2, CI_IDLE_PCB
+ ld r3, r2, CI_INIT_STACK
bsr.n _C_LABEL(secondary_main)
- addu r31, r3, USIZE /* switch to idle stack */
+ addu r31, r3, USIZE /* switch to startup stack */
#endif /* MULTIPROCESSOR */
@@ -383,14 +383,6 @@ ASLOCAL(slavestack_end)
#endif
/*
- * Main processor's idle pcb and stack.
- * Should be page aligned.
- */
- .align PAGE_SIZE
-GLOBAL(idle_u)
- space USIZE
-
-/*
* Process 0's u.
* Should be page aligned.
*/
diff --git a/sys/arch/aviion/aviion/machdep.c b/sys/arch/aviion/aviion/machdep.c
index 4e7077db979..588900afba2 100644
--- a/sys/arch/aviion/aviion/machdep.c
+++ b/sys/arch/aviion/aviion/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.12 2007/10/13 12:55:20 miod Exp $ */
+/* $OpenBSD: machdep.c,v 1.13 2007/11/06 21:42:55 miod Exp $ */
/*
* Copyright (c) 1998, 1999, 2000, 2001 Steve Murphree, Jr.
* Copyright (c) 1996 Nivas Madhur
@@ -585,11 +585,13 @@ secondary_pre_main()
pmap_bootstrap_cpu(ci->ci_cpuid);
/*
* Allocate UPAGES contiguous pages for the idle PCB and stack.
*/
- ci->ci_idle_pcb = (struct pcb *)uvm_km_zalloc(kernel_map, USPACE);
- if (ci->ci_idle_pcb == NULL) {
- printf("cpu%d: unable to allocate idle stack\n", ci->ci_cpuid);
+ ci->ci_init_stack = uvm_km_zalloc(kernel_map, USPACE);
+ if (ci->ci_init_stack == (vaddr_t)NULL) {
+ printf("cpu%d: unable to allocate startup stack\n",
+ ci->ci_cpuid);
+ for (;;) ;
}
}
@@ -585,11 +585,13 @@ secondary_pre_main()
pmap_bootstrap_cpu(ci->ci_cpuid);
/*
- * Allocate UPAGES contiguous pages for the idle PCB and stack.
+ * Allocate UPAGES contiguous pages for the startup stack.
*/